vfbLib.typing.Instruction
=========================

.. currentmodule:: vfbLib.typing

.. autoclass:: Instruction
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Instruction.__init__
      ~Instruction.clear
      ~Instruction.copy
      ~Instruction.fromkeys
      ~Instruction.get
      ~Instruction.items
      ~Instruction.keys
      ~Instruction.pop
      ~Instruction.popitem
      ~Instruction.setdefault
      ~Instruction.update
      ~Instruction.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Instruction.cmd
      ~Instruction.params
   
   